#!/usr/bin/env python
# -*- coding: utf-8 -*-

import platform
from setuptools import setup

setup(
    name='easy_ansible',
    version='1.0.1',
    author='CcccFz',
    author_email='ccccfz@163.com',
    url='https://github.com/CcccFz/easy-ansible',
    description='An ansible api that can be used directly and easily',
    packages=['easy_ansible'],
    install_requires=[],
    entry_points={}
)